package org.acme.optaplanner.rest;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class TimeslotResourceIT extends TimeslotResourceTest {

}
